function mphsave(varargin)
% MPHSAVE Save a COMSOL model
%
%   MPHSAVE saves the model that is loaded on the server
%
%   MPHSAVE(MODEL) saves the COMSOL model object MODEL.
%
%   MPHSAVE(MODEL,FILENAME) saves the COMSOL model object MODEL to the file
%   named FILENAME.
%
%   MPHSAVE(FILENAME) saves the unique COMSOL model that is loaded on the 
%   server to the file named FILENAME.
%
%   MPHSAVE(MTAG) saves the COMSOL model loaded on the COMSOL server with 
%   the tag MTAG.
%
%   MPHSAVE(MTAG,FILENAME) saves the COMSOL model loaded on the COMSOL 
%   server with the tag MTAG to the file named FILENAME.
%
%   Valid property/value pairs include:
%   Property   Value/{Default}     Description
%   -----------------------------------------------------------------------
%   Component    {'off'} | 'on'      Save M-file using component syntax
%   Copy         {'off'} | 'on'      Save a copy of the model
%   Description  String              Set or append model description
%   ExcludeData  'on' | 'off'        Exclude built, computed, and plotted 
%                                    data
%   Filenameis   {'fullpath'} |      Use filename as the selected type
%                'name' | 'path'
%   Optimize     'speed' |           Optimize MPH-files for speed or size
%                'size'
%   Store        {'on'} | 'off'      Store the filename in most recently
%                                    used files
%
%   If the file name is not provided, the model has to be saved previously.
%   If the file name does not include a path, the file is saved relatively 
%   to the current path in MATLAB.
%   The model can be saved as an MPH-file, Java-file, VBA-file or M-file. 
%   The file extension determines which format that is saved.
%
%   See also: mphopen, mphload

%   Copyright 2011-2021 COMSOL
